/**
 * Parses scenes from BBcode to HTML.
 */
function KoboldParser() {
    // PRIVATE MEMBERS \\       var private = "test";

    var colorClasses = {
        red: "red",
        bred: "brightred",
        dred: "darkred",
        blue: "blue",
        pink: "pink",
        ppink: "palepink",
        purple: "purple",
        green: "green",
        orange: "orange",
        white: "white",
        black: "black",
        brown: "brown"
    };

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Replaces paragraph bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function title(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[t\]/g, '<div class="title fancy">');
        toReturn = toReturn.replace(/\[\/t\]/g, "</div>");
        return toReturn;
    }

    /**
     * Replaces paragraph bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function subtitle(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[st\]/g, '<div class="subtitle">');
        toReturn = toReturn.replace(/\[\/st\]/g, "</div>");
        return toReturn;
    }

    /**
     * Replaces paragraph bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function paragraph(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[p\]/g, '<div class="text">');
        toReturn = toReturn.replace(/\[\/p\]/g, "</div>");
        return toReturn;
    }

    /**
     * Replaces center bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function center(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[c\]/g, '<div class="center">');
        toReturn = toReturn.replace(/\[\/c\]/g, "</div>");
        return toReturn;
    }

    /**
     * Replaces bold bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function bold(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[b\]/g, '<span class="bold">');
        toReturn = toReturn.replace(/\[\/b\]/g, "</span>");
        return toReturn;
    }

    /**
     * Replaces italic bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function italic(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[i\]/g, '<span class="italic">');
        toReturn = toReturn.replace(/\[\/i\]/g, "</span>");
        return toReturn;
    }
    
    /**
     * Replaces underline bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function strikethrough(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[s\]/g, '<span class="strikethrough">');
        toReturn = toReturn.replace(/\[\/s\]/g, "</span>");
        return toReturn;
    }
    
    /**
     * Replaces underline bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function underline(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[u\]/g, '<span class="underline">');
        toReturn = toReturn.replace(/\[\/u\]/g, "</span>");
        return toReturn;
    }

    /**
     * Replaces small bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function small(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[small\]/g, '<span class="small">');
        toReturn = toReturn.replace(/\[\/small\]/g, "</span>");
        return toReturn;
    }

    /**
     * Replaces sub bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function sub(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[sub\]/g, '<span class="small">');
        toReturn = toReturn.replace(/\[\/sub\]/g, "</span>");
        return toReturn;
    }

    /**
     * Replaces big bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function big(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[big\]/g, '<span class="big">');
        toReturn = toReturn.replace(/\[\/big\]/g, "</span>");
        return toReturn;
    }
    
    /**
     * Replaces sneaky bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function sneaky(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[sneak\]/g, '<span class="sneakytext">');
        toReturn = toReturn.replace(/\[\/sneak\]/g, "</span>");
        return toReturn;
    }

    /**
     * Returns the class corresponding with the color,
     * or null if no such class exists.
     * @param {string} color The color to get a class for.
     * @returns {string} The class of the color, or null if it is a bad color.
     */
    function colorClass(color) {
        if (colorClasses.hasOwnProperty(color)) {
            return colorClasses[color];
        } else {
            return null;
        }
    }

    /**
     * Replaces the first occurrence of needle with an appropriate color span,
     * or removes the occurrence altogether if it does not match a predefined color,
     * replacing it with a <span>.
     * @param {string} string The bbcode string in which to replace.
     * @param {array} needle The color-needle.
     * @returns {string} The replaced string.
     */
    function replaceColor(string, needle) {
        var toReturn = string;
        var color = needle;
        color = color.substring(7); // Remove "[color="
        color = color.slice(0, -1); // remove "]"
        var css = colorClass(color);
        if (css) {
            toReturn = toReturn.replace(needle, `<span class="${css}">`);
        } else {
            toReturn = toReturn.replace(needle, `<span>`);
        }
        return toReturn;
    }

    /**
     * Replaces each of the needles with its appropriate color, if any.
     * @param {string} string The bbcode string in which to replace.
     * @param {array} needles The color-needles.
     * @returns {string} The replaced string.
     */
    function replaceColors(string, needles) {
        var toReturn = string;
        if (!needles) {
            return toReturn;
        }
        for (var i = 0; i < needles.length; i++) {
            toReturn = replaceColor(toReturn, needles[i]);
        }
        return toReturn;
    }

    /**
     * Replaces color bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function color(string) {
        var toReturn = string;
        var needles = toReturn.match(/\[color=([^\]]{3,6})\]/g);
        toReturn = replaceColors(toReturn, needles);
        toReturn = toReturn.replace(/\[\/color\]/g, "</span>");
        return toReturn;
    }
    
    /**
     * Replaces comment bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function comment(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[com\]/g, '<span class="invisible">');
        toReturn = toReturn.replace(/\[\/com\]/g, "</span>");
        return toReturn;
    }
    
    /**
     * Replaces newline bbcode with its HTML representation.
     * @param {string} string The bbcode string in which to replace.
     * @returns {string} The replaced string.
     */
    function newline(string) {
        var toReturn = string;
        toReturn = toReturn.replace(/\[nl\]/g, '<br/>');
        toReturn = toReturn.replace(/\[\/nl\]/g, "");
        return toReturn;
    }

    /**
     * Transforms all BBcode tags into their appropriate HTML counterparts.
     * @param {string} string The message to transform.
     * @returns {string} The transformed message.
     */
    function tags(string) {
        var toReturn = string;
        toReturn = title(toReturn);
        toReturn = subtitle(toReturn);
        toReturn = paragraph(toReturn);
        toReturn = center(toReturn);
        toReturn = bold(toReturn);
        toReturn = italic(toReturn);
        toReturn = strikethrough(toReturn);
        toReturn = underline(toReturn);
        toReturn = small(toReturn);
        toReturn = sub(toReturn);
        toReturn = big(toReturn);
        toReturn = sneaky(toReturn);
        toReturn = color(toReturn);
        toReturn = comment(toReturn);
        toReturn = newline(toReturn);
        return toReturn;
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Parses the BBcode string to HTML.
     * Returns the BBcode string if the
     * @param {string} bbcode The BBcode.
     * @returns {string} HTML representing the BBcode.
     */
    this.parse = function (bbcode) {
        return tags(bbcode);
    };
}
