/**
 * Grab section of the unknown scene.
 * @param {ForestController} controller The forest controller.
 */
function ForestUnknownGrab(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `grabContinueButton`;
    var toEnveloped = new ForestUnknownEnveloped(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Time appears to slow down as adrenaline floods your system.
                            You can see the spiky tentacle lunging towards you in slow motion.
                            It undoubtebly seeks to either hurt you or grab you.
                            But you bet it [i]isn't[/i] counting on [i]you[/i] grabbing [i]it[/i] first.
                        [/p]
                        [p]
                            You extend your arm towards the surging tentacle, your fingers spread, yet arched, ready to clamp down onto the plant's appendage.
                            As the tendril rushes past your prepared hand, you spring your trap, 
                            snagging it mid-flight, squeezing it with all of your might to halt its advance, and to trap it within your grasp.
                            While at first, you are proud of your achievement, 
                            it isn't until you feel a sharp, stinging pain emanating from your hand, that you realize your folly.
                        [/p]
                        [p]
                            You just [b]squeezed down[/b] on nature's equivalent of [b]barbed wire[/b].
                            The tendril's thorns have punctured your soft palm and the underside of your fingers, sinking deeply into your flesh.
                            You howl out in pain.
                            Tossing the tentacle to the ground, you clutch your bleeding hand, taking a moment to inspect the injury.
                            While some of the wounds are pretty deep, you don't think anything [i]crucial[/i] was damaged.
                            At least you can still move all of your fingers.
                        [/p]
                        [p]
                            Sensing an opportunity, the plant immediately takes advantage of your distracted state.
                            While you're still attempting to judge just [i]how badly[/i] your hand was hurt,
                            two tentacles sneakily inch along the forest floor, encircling you.
                            After crossing one another and then some, they swoop back towards the central mass of the monstrosity as a unified [i]rope[/i],
                            catching the back of your feet, yanking your legs out from underneath you.
                        [/p]
                        [p]
                            Surprised, you let out a loud yelp as you are yanked off your feet, falling backwards onto the ground,
                            your head smacking against an unfortunately placed rock while the rest of your body comes to rest onto a bed of leaves with a soft thud.
                            Dazed, you phase out for a few moments.
                            Your vision is blurry, and the entire world seems to be rocking back and forth.
                            You notice something moving, but you can't quite make out what.
                            You can feel something crawling onto your arms, wrapping around them tightly.
                            [i]Oh no.[/i]
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.unknown.yank.grab.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unknown.yank.grab.continue();
            loadNextPart(toEnveloped);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "forestUnknownGrab";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unknown.yank.base.get() !== ForestUnknownYankChoice.GRAB) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.unknown.yank.hit.change(); // Hit and grab have the same change.
        part += buildChoice();
        part += toEnveloped.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unknown.yank.base.get() !== ForestUnknownYankChoice.GRAB) {
            return;
        }
        
        toEnveloped.registerListeners();

        if (ctrl.unknown.yank.grab.continued()) {
            return;
        }

        registerContinueListener();
    };
}
