/**
 * Controller for the Varanar Night Two scene.
 * @param {string} sceneId The id of the scene.
 */
function NightTwoController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = false;
    this.nextSceneName = "MorningThree";
    this.nextFolderName = "Varanar";

    this.misc = new MiscController(id);

    this.arrival = new ChangeController(id, "arrival", function () {
        global.kobold.status.mental.increase(15, "Amazed by Varanar");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Amazement", "Sanity", +15)
        ]);
    });

    this.stage = new ContinueController(id, "stage");
    this.runin = new ChoiceController(id, "runin");

    this.flee = new UndoController(id, "flee", function change() {
        var sanityBacklog = new ChoiceController(id, "fleeSanityBL"); // Todo: Make framework for this
        var staminaBacklog = new ChoiceController(id, "fleeStaminaBL");
        sanityBacklog.set(global.kobold.status.mental.lasthit);
        staminaBacklog.set(global.kobold.status.stamina.lasthit);
        global.kobold.status.mental.decrease(5, "Being chased");
        global.kobold.status.stamina.decrease(5, "Light jogging");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Being pursued", "Sanity", -5),
            new Change("Fearful jogging", "Stamina", -5)
        ]);
    }, function undoChange() {
        var sanityBacklog = new ChoiceController(id, "fleeSanityBL"); // Todo: Make framework for this
        var staminaBacklog = new ChoiceController(id, "fleeStaminaBL");
        global.kobold.status.mental.increase(5, sanityBacklog.get());
        global.kobold.status.stamina.increase(5, staminaBacklog.get());
        sanityBacklog.unset();
        staminaBacklog.unset();
    });

    this.alley = new ChoiceController(id, "alley");
    this.hide = new ChoiceController(id, "hide");

    this.hideStay = new ChangeController(id, "hideStay", function change() {
        global.kobold.status.physical.decrease(5, "Breathing in miasma");
        global.kobold.status.mental.decrease(25, "Got pissed on");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Miasma", "Health", -5),
            new Change("Pissed on", "Sanity", -25)
        ]);
    });

    this.hideAttack = new ChangeController(id, "hideAttack", function change() {
        global.kobold.status.mental.increase(10, "Righteous justice");
        global.kobold.status.mental.decrease(25, "Manual neutering");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Righteous justice", "Sanity", -10),
            new Change("Manual neutering", "Sanity", -25)
        ]);
    });

    this.alleyRunSuccess = new ChangeController(id, "alleyRunSuccess", function change() {
        global.kobold.status.physical.increase(5, "Good workout");
        global.kobold.status.mental.increase(10, "Showcased skill");
        global.kobold.status.stamina.decrease(10, "Parkouring");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Good workout", "Health", +5),
            new Change("Skillful escape", "Sanity", +10),
            new Change("Parkouring", "Stamina", -10)
        ]);
    });

    this.alleyRunFail = new UndoController(id, "alleyRunFail", function change() {
        var healthBacklog = new ChoiceController(id, "alleyRunFailHealthBL");
        var sanityBacklog = new ChoiceController(id, "alleyRunFailSanityBL");
        var staminaBacklog = new ChoiceController(id, "alleyRunFailStaminaBL");
        healthBacklog.set(global.kobold.status.physical.lasthit);
        sanityBacklog.set(global.kobold.status.mental.lasthit);
        staminaBacklog.set(global.kobold.status.stamina.lasthit);
        global.kobold.status.physical.decrease(5, "Fell down");
        global.kobold.status.mental.decrease(10, "Plan failed");
        global.kobold.status.stamina.decrease(5, "Attempted climbing");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Fell down", "Health", -5),
            new Change("Plan failed", "Sanity", -5),
            new Change("Cornered", "Sanity", -5),
            new Change("Attmpted parkouring", "Stamina", -5)
        ]);
    }, function undo() {
        var healthBacklog = new ChoiceController(id, "alleyRunFailHealthBL");
        var sanityBacklog = new ChoiceController(id, "alleyRunFailSanityBL"); // Todo: Make framework for this
        var staminaBacklog = new ChoiceController(id, "alleyRunFailStaminaBL");
        global.kobold.status.physical.increase(5, healthBacklog);
        global.kobold.status.mental.increase(10, sanityBacklog.get());
        global.kobold.status.stamina.increase(5, staminaBacklog.get());
        healthBacklog.unset();
        sanityBacklog.unset();
        staminaBacklog.unset();
    });

    this.alleyEager = new ChangeController(id, "alleyEager", function change() {

    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.alleyStay = new ChangeController(id, "alleyStay", function change() {
        if(global.kobold.inventory.equipment.shirt) {
            global.kobold.inventory.equipment.shirt.stain("Piss");
        }
        if(global.kobold.inventory.equipment.pants) {
            global.kobold.inventory.equipment.pants.stain("Urine");
        }
        if(global.kobold.inventory.equipment.underwear) {
            global.kobold.inventory.equipment.underwear.stain("Pee");
        }
        global.kobold.status.physical.decrease(5, "Unsanitary actions");
        global.kobold.status.mental.decrease(25, "Got pissed on");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Unsanitary", "Health", -5),
            new Change("Unwilling watersports", "Sanity", -25)
        ]);
    });

    this.runGetaway = new ChangeController(id, "runGetaway", function change() {
        global.kobold.status.physical.decrease(10, "Overexertion");
        global.kobold.status.mental.increase(10, "Escaped certain death");
        global.kobold.status.stamina.decrease(25, "Running for your life");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Overexertion", "Health", -10),
            new Change("Escaped certain death", "Sanity", +10),
            new Change("Out of breath", "Stamina", -25)
        ]);
    });

    this.runSurvive = new ChangeController(id, "runSurvive", function change() {
        var stamina = that.misc.stamina();
        var endurance = that.misc.endurance();
        var damage = Math.floor(250 / endurance);
        global.kobold.status.physical.decrease(damage, "Beat up by humans");
        global.kobold.status.mental.decrease(20, "Victim complex");
        global.kobold.status.stamina.decrease(stamina, "Ran for your life");
    }, function changeNote() {
        var stamina = that.misc.stamina();
        var endurance = that.misc.endurance();
        var damage = Math.floor(250 / endurance);
        return global.ui.change.buildNotification([
            new Change("Beatdown", "Health", -damage),
            new Change("Victim complex", "Sanity", -20),
            new Change("Gave it your all", "Stamina", -stamina)
        ]);
    });


    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

}
