/**
 * Flee section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoHideStayContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var pants = ctrl.misc.pants();
        var shirt = ctrl.misc.shirt();
        var clothes = shirt || pants;
        var toReturn = `[p]
                            The moment the human leaves the alleyway, you instantly rise to your feet and clean your face off with your single dry hand.
                            You feel completely [b]disgusted[/b].
                            Unable to weather the stench for even a second longer, you step out from behind the barrels,
                            and wander deeper into the alleyway in search of some fresh air.
                            At this point, you don't even [b]care[/b] about getting caught anymore.
                            The group seems to have wander off, but you'd have broken your cover even if they hadn't.
                        [/p]
                        [p]
                            Leaning against the brick wall sealing off the alley, you bend over and retch for a few solid minutes straight,
                            stuck in between the intense urge to vomit and the desire [b]not[/b] to let your last meal go to waste.
                            You can still [b]reek[/b] the human's piss, splatters of which linger on your ${clothes ? `clothing` : `body`} and on your face.
                            You fear the scent may have [b]seeped[/b] into your very scales, even though you didn't get [i]that much[/i] of it on you.
                        [/p]
                        [p]
                            While sickened by the lasting urine-smell, you are grateful that at least the fragrance of refuse hasn't reached this end of the alley.
                            At least here, you don't have to suffer the mixture of sweaty human groin, reeking barrels and dehydrated pee all at once.
                            Slowly but surely, your retching comes to an end.
                            Holding your breath, you walk past the scene of the crime, 
                            looking everywhere [b]but[/b] at the stagnating puddle in between the barrels to check whether the hoodlums are still around or not.
                            The street seems empty.
                            You think they've left.
                            You [b]hope[/b] they've left.
                        [/p]
                        [p]
                            You sneak out of the alleyway, before quickly and quietly making your way back to a more [i]hospitable[/i] part of town.
                            While, at first, you curse the small, chilly morning wind that picks up,
                            you soon learn to appreciate it for washing the stench of piss off of you,
                            and for fully drying your ${clothes ? `clothes` : `body`} in a matter of minutes.
                        [/p]
                        [p]
                            After removing yourself from the [i]brothel district[/i] proper,
                            you start walking back towards the town square,
                            where your [i]urban adventure[/i] began.
                            As you begin to near it, you notice the sun slowly rising above the rooftops.
                            You must have lost track of time while exploring the city.
                            Or maybe you were left retching in the alleyway for a longer time than you care to remember.
                            Either way, you guess you won't be sleeping tonight.
                        [/p]
                        [p]
                            The twinkle of magic you felt at midnight has all but faded, giving way to a sense of [b]vulnerability[/b].
                            You are but a lone, weak, small, kobold in a big city filled with people who can and [b]want[/b] to maim,
                            hurt, kill and perhaps even [b]rape[/b] you.
                            If you let your guard down for even one moment, it could cost you your money, your life or both.
                            And next time, the drunk taking a leak against your hiding spot might actually [b]notice[/b] you.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.hideStay.continued()) {
            return "";
        }

        global.ui.applyTheme("varanar_morning");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.hideStay.continued()) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}
